@@ -1,8 +1,8 @@
 use {
-    crate::{state::*, errors::*},
+    crate::{state::*, errors::ErrorCode},
     anchor_lang::{prelude::*, solana_program::program::invoke_signed, AccountsClose},
     anchor_spl::{token::{self, Token, TokenAccount, Mint, Transfer, ThawAccount, CloseAccount}},
-    mpl_token_metadata::{instruction::thaw_delegated_account, utils::{assert_derivation,assert_initialized}},
+    mpl_token_metadata::{instruction::thaw_delegated_account, utils::{assert_derivation, assert_initialized}},
 };
 
 #[derive(Accounts)]
@@ -23,13 +23,16 @@ pub struct InvalidateCtx<'info> {
     recipient_token_account: Box<Account<'info, TokenAccount>>,
 
     // invalidator
-    #[account(mut, constraint = token_manager.invalidators.contains(&invalidator.key()) @ ErrorCode::InvalidInvalidator)]
+    #[account(constraint = token_manager.invalidators.contains(&invalidator.key()) @ ErrorCode::InvalidInvalidator)]
     invalidator: Signer<'info>,
-    
+    /// CHECK: This is not dangerous because we don't read or write from this account
+    #[account(mut)]
+    collector: AccountInfo<'info>,
+
     token_program: Program<'info, Token>,
 }
 
-pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, InvalidateCtx<'info>>) -> ProgramResult {
+pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, InvalidateCtx<'info>>) -> Result<()> {
     let token_manager = &mut ctx.accounts.token_manager;
     let remaining_accs = &mut ctx.remaining_accounts.iter();
 
@@ -38,43 +41,6 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
     let token_manager_seeds = &[TOKEN_MANAGER_SEED.as_bytes(), mint.as_ref(), &[token_manager.bump]];
     let token_manager_signer = &[&token_manager_seeds[..]];
 
-    if token_manager.payment_mint != None {
-        let payment_token_account_info = next_account_info(remaining_accs)?;
-        let payment_token_account = Account::<TokenAccount>::try_from(payment_token_account_info)?;
-
-        if payment_token_account.mint != token_manager.payment_mint.unwrap() { return Err(ErrorCode::PublicKeyMismatch.into()); }
-        if payment_token_account.owner != token_manager.key() { return Err(ErrorCode::PublicKeyMismatch.into()); }
-        // assert_keys_eq!(payment_token_account.mint, token_manager.payment_mint.unwrap());
-        // assert_keys_eq!(payment_token_account.owner, token_manager.key());
-
-        let issuer_payment_token_account_info = next_account_info(remaining_accs)?;
-        let issuer_payment_token_account = Account::<TokenAccount>::try_from(issuer_payment_token_account_info)?;
-
-        if issuer_payment_token_account.mint != token_manager.payment_mint.unwrap() { return Err(ErrorCode::PublicKeyMismatch.into()); }
-        if issuer_payment_token_account.owner != token_manager.issuer { return Err(ErrorCode::PublicKeyMismatch.into()); }
-        // assert_keys_eq!(issuer_payment_token_account.mint, token_manager.payment_mint.unwrap());
-        // assert_keys_eq!(issuer_payment_token_account.owner, token_manager.issuer);
-
-        let cpi_accounts = Transfer {
-            from: payment_token_account_info.clone(),
-            to: issuer_payment_token_account_info.clone(),
-            authority: token_manager.to_account_info(),
-        };
-        let cpi_program = ctx.accounts.token_program.to_account_info();
-        let cpi_context = CpiContext::new(cpi_program, cpi_accounts).with_signer(token_manager_signer);
-        token::transfer(cpi_context, payment_token_account.amount)?;
-    
-        // close token account
-        let cpi_accounts = CloseAccount {
-            account: payment_token_account_info.to_account_info(),
-            destination: ctx.accounts.invalidator.to_account_info(),
-            authority: token_manager.to_account_info(),
-        };
-        let cpi_program = ctx.accounts.token_program.to_account_info();
-        let cpi_context = CpiContext::new(cpi_program, cpi_accounts).with_signer(token_manager_signer);
-        token::close_account(cpi_context)?;
-    }
-
     if token_manager.state == TokenManagerState::Claimed as u8 {
         if token_manager.kind == TokenManagerKind::Managed as u8 {
             let mint_manager_info = next_account_info(remaining_accs)?;
@@ -100,7 +66,7 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
             let edition_info = next_account_info(remaining_accs)?;
             let metadata_program = next_account_info(remaining_accs)?;
             // edition will be validated by metadata_program
-            if metadata_program.key() != mpl_token_metadata::id() { return Err(ErrorCode::InvalidMetadataProgramId.into()); }
+            if metadata_program.key() != mpl_token_metadata::id() { return Err(error!(ErrorCode::InvalidMetadataProgramId)); }
             // assert_keys_eq!(metadata_program.key(), mpl_token_metadata::id());
             
             invoke_signed(
@@ -128,12 +94,12 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
         let return_token_account_info = next_account_info(remaining_accs)?;
         let return_token_account: spl_token::state::Account = assert_initialized(return_token_account_info)?;
         if token_manager.receipt_mint == None {
-            if return_token_account.owner != token_manager.issuer { return Err(ErrorCode::InvalidIssuerTokenAccount.into()); }
+            if return_token_account.owner != token_manager.issuer { return Err(error!(ErrorCode::InvalidIssuerTokenAccount)); }
         } else {
             let receipt_token_account_info = next_account_info(remaining_accs)?;
             let receipt_token_account: spl_token::state::Account = assert_initialized(receipt_token_account_info)?;
-            if !(receipt_token_account.mint == token_manager.receipt_mint.unwrap() && receipt_token_account.amount > 0) { return Err(ErrorCode::InvalidReceiptMintAccount.into())}
-            if receipt_token_account.owner != return_token_account.owner { return Err(ErrorCode::InvalidReceiptMintOwner.into()); }
+            if !(receipt_token_account.mint == token_manager.receipt_mint.unwrap() && receipt_token_account.amount > 0) { return Err(error!(ErrorCode::InvalidReceiptMintAccount))}
+            if receipt_token_account.owner != return_token_account.owner { return Err(error!(ErrorCode::InvalidReceiptMintOwner)); }
         }
 
         // transfer back to issuer
@@ -150,7 +116,7 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
     // close token_manager_token_account
     let cpi_accounts = CloseAccount {
         account: ctx.accounts.token_manager_token_account.to_account_info(),
-        destination: ctx.accounts.invalidator.to_account_info(),
+        destination: ctx.accounts.collector.to_account_info(),
         authority: token_manager.to_account_info(),
     };
     let cpi_program = ctx.accounts.token_program.to_account_info();
@@ -158,7 +124,7 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
     token::close_account(cpi_context)?;
 
     if token_manager.invalidation_type != InvalidationType::Invalidate as u8 {
-        token_manager.close(ctx.accounts.invalidator.to_account_info())?;
+        token_manager.close(ctx.accounts.collector.to_account_info())?;
     }
     return Ok(())
 }
